change_node_colour: Change the colour of a given node

Description Usage Arguments Details Value

View source: R/change_node_colour.R

Description

Change the colour of any nodes matching a pattern

Usage

1

Arguments

x

dot file as a character vector

pattern

Regular expression used to define one or more nodes

col

The new node colour

Details

Finds nodes matching the regular expression provided and sets their colour as provided

Value

A character vector


steveped/spBioUtils documentation built on Sept. 25, 2021, 7:22 p.m.