Description Usage Arguments Details Methods (by class)
Display one corner of a large matrix-like object
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 |
x |
A matrix or data.frame |
... |
arguments to be passed to or from other methods. |
corner |
The corner to show |
n |
The number of rows and columns to show |
This provides an alternative to head for matrix-like objects with many columns
matrix: Display one corner of a large matrix-like object
data.frame: Display one corner of a large matrix-like object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.