rm_dot_node: Remove a single node from a snakemake dag

Description Usage Arguments Details Value

View source: R/rm_dot_node.R

Description

Remove a single node from a snakemake dag

Usage

1
rm_dot_node(x, node = "\"all\"")

Arguments

x

dot file as a character vector

node

The name of node to drop

Details

Takes a dot file as a character vector, such as would be obtained using readLines, and removes a single node. Commonly this is the 'all' node as might be produced from a snakemake rulegraph

The resultant graph can then be visualised using grViz from the package DiagrammeR, or passed into any function which takes dot format as a character vector

Value

A character vector


steveped/spBioUtils documentation built on Sept. 25, 2021, 7:22 p.m.