Description Usage Arguments Details Value
View source: R/add_input_node.R
Add an additional input node to a dot graph
1 2 3 4 5 6 7 | add_input_node(
x,
node = "raw_data",
ignore = "(get|build|make|install)",
col = "#000000",
style = "rectangle"
)
|
x |
dot file as a character vector |
node |
The name of the node to add |
ignore |
Regular expression used to define any orphan nodes which should not be added to |
col |
The colour for the input node |
style |
The shape of the node |
Takes a dot file as a character vector, such as would be obtained
using readLines, and adds a node to any existing nodes with no parental node.
Orphan nodes which should be ignored can be specified using the pattern in
the ignore argument.
A character vector
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.