Description Usage Arguments Details Value
View source: R/change_node_colour.R
Change the colour of any nodes matching a pattern
1 | change_node_colour(x, pattern, col)
|
x |
dot file as a character vector |
pattern |
Regular expression used to define one or more nodes |
col |
The new node colour |
Finds nodes matching the regular expression provided and sets their colour as provided
A character vector
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.