Description Usage Arguments Details Value
Remove a single node from a snakemake dag
1 | rm_dot_node(x, node = "\"all\"")
|
x |
dot file as a character vector |
node |
The name of node to drop |
Takes a dot file as a character vector, such as would be obtained using readLines, and removes a single node. Commonly this is the 'all' node as might be produced from a snakemake rulegraph
The resultant graph can then be visualised using grViz from the
package DiagrammeR, or passed into any function which takes dot format as a
character vector
A character vector
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.